package VMOMI::IoFilterType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
